outlook — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- export »

# outlook

`camelot.view.export.outlook.` `logger` = <logging.Logger object at 0xc6e184c>

  Functions to send files by email using outlook

  After http://win32com.goermezer.de/content/view/227/192/

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- export »

Comments
blog comments powered by Disqus